@@ -7,11 +7,11 @@ Elive - Elluminate Live! Manager (ELM) Command Toolkit bindings
 
 =head1 VERSION
 
-Version 1.33
+Version 1.34
 
 =cut
 
-our $VERSION = '1.33';
+our $VERSION = '1.34';
 
 use 5.008003;
 
@@ -318,7 +318,7 @@ see the README file.
 
 =head2 Related CPAN Modules
 
-L<Elive::StandardV3> - this module implements the alternate Elluminate I<Live!> Standard Bridge API (v3). 
+L<Elive::StandardV3> - this module implements the alternate Elluminate I<Live!> Standard Bridge API (v3) for C<ELM> and C<SAS>. 
 
 =head2 Elluminate Documentation
 
@@ -399,7 +399,7 @@ assistance with the development of this module.
 
 =head1 COPYRIGHT & LICENSE
 
-Copyright 2009-2012 David Warring, all rights reserved.
+Copyright 2009-2015 David Warring, all rights reserved.
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
